
//THE FOLLOWING PROGRAMS ARE NEEDED:

* REGHDFE: module to perform linear or instrumental-variable regression absorbing any number of high-dimensional fixed effects
* COEFPLOT: module to plot regression coefficients and other results 
* grc1leg:  Combine graphs into one graph with a common legend.
* OUTREG2: module to arrange regression outputs into an illustrative table
* RDROBUST: for rdplots
* IVREGHDFE: module for extended instrumental variable regressions with multiple levels of fixed effects


//SET GLOBAL PATH TO REPLICATION FOLDER:
global root "C:\Users\jbn102\Dropbox\Current_work\London_temperature\replication_files"
*global root "C:\Users\walke\Dropbox\London_temperature\replication_files"

********************************
** CONSTRUCT MAIN DATA        **
********************************

//INLOAD MAIN DEATH DATA
use "$root\raw_data\aggregate_mortality_weekly_data.dta", clear 

//MERGE WITH OXFORD TEMPERATURE DATA 
merge m:1 year week using "$root\raw_data\oxford_temp_weekly_data.dta"
drop if _merge==2
drop _merge

//MERGE IN DIGESTIVE DEATH DATA
merge m:1 year week using "$root\raw_data\digestive_mortality_weekly_data.dta"
drop if _merge==2
drop _merge
********************************************************************************


//GENERATE MONTH AND DECADE INDICATORS 
gen month=.
replace month=1 if week>= 1 & week<=5
replace month=2 if week>= 6 & week<=9
replace month=3 if week>= 10 & week<=13
replace month=4 if week>= 14 & week<=17
replace month=5 if week>= 18 & week<=22
replace month=6 if week>= 23 & week<=26
replace month=7 if week>= 27 & week<=31
replace month=8 if week>= 23 & week<=35
replace month=9 if week>= 36 & week<=39
replace month=10 if week>= 40 & week<=44
replace month=11 if week>= 45 & week<=48
replace month=12 if week>= 49 & week<=53
egen month_year=group(month year)

gen decade_1=.
replace decade_1= 1 if year>=1873 & year<=1879
replace decade_1= 2 if year>=1880 & year<=1889
replace decade_1= 3 if year>=1890 & year<=1899
replace decade_1= 4 if year>=1900 & year<=1914
replace decade_1= 5 if year>=1919 & year<=1929
replace decade_1= 6 if year>=1930 & year<=1939
replace decade_1= 7 if year>=1949 & year<=1965
*********************************************************************************

//GENERATE OUTCOMES:
gen lntotaldeaths=ln(totaldeaths)
gen lninfantdeaths =ln(infants01)
gen lnbirths=ln(births)
gen lnnondigestive=ln(totaldeaths-digestive_all)
gen lndigestive_all=ln(digestive_all)
gen lnnoninfantdeaths=ln(totaldeaths-infants01)
gen infant_ratio=(infants01/ (totaldeaths-infants01) )*100
gen digestive_ratio=(digestive_all/(totaldeaths - digestive_all))*100
gen inf_digestive_ratio=(digestive_0_1/(infants01 - digestive_0_1))*100

*INFANT MORATLITY RATE
sort year week
gen sum1_births=sum(births) if year<=1914
gen avg1_births=(sum1_births-sum1_births[_n-52])/52 if year<=1914
gen sum2_births=sum(births) if year>=1919 & year<=1939
gen avg2_births=(sum2_births-sum2_births[_n-52])/52 if year>=1914 & year<=1939
gen sum3_births=sum(births) if year>=1949
gen avg3_births=(sum3_births-sum3_births[_n-52])/52 if year>=1949
egen avg_births=rowmax(avg1_births avg2_births avg3_births)
drop sum1_births sum2_births sum3_births avg1_births avg2_births avg3_births
replace avg_births=. if year==1919 & week==53
gen avg_imr=infants01*100/avg_births
gen lnavg_imr=ln(avg_imr)  
********************************************************************************


//TEMPERATURE VARIABLES
gen extreme_quantile=.
replace extreme_quantile=1 if oxford_min_temp<25
replace extreme_quantile=2 if oxford_min_temp>=25 & oxford_min_temp<30
replace extreme_quantile=3 if oxford_min_temp>=30 & oxford_min_temp<35
replace extreme_quantile=5 if oxford_max_temp>=65 & oxford_max_temp<70
replace extreme_quantile=6 if oxford_max_temp>=70 & oxford_max_temp<75
replace extreme_quantile=7 if oxford_max_temp>=75 & oxford_max_temp<80
replace extreme_quantile=8 if oxford_max_temp>=80

replace extreme_quantile=4 if extreme_quantile==. //COMPARISON BIN

*BINS
forvalues i = 1/8{
gen temp_q`i'= 1 if extreme_quantile==`i'
replace temp_q`i'=0 if temp_q`i'==. 
} 

*LEAD/LAGS FOR BINS 
foreach dist of numlist 1(1)5{
foreach i of numlist 1 2 3 4 5 6 7 8{
gen temp_F`dist'_q`i'= temp_q`i'[_n+`dist']
}
}
foreach dist of numlist 7(1)0{
foreach i of numlist 1 2 3 4 5 6 7 8{
gen temp_L`dist'_q`i'= temp_q`i'[_n-`dist']
}
}
*MISSING VALUES FOR BREAKS IN DATA 
foreach w of numlist 1(1)7{
foreach i of numlist 1 2 3 4 5 6 7 8{
replace temp_L`w'_q`i'=. if week<=`w' & (year==1919 | year==1949)
}
}
foreach w of numlist 1(1)5{
foreach i of numlist 1 2 3 4 5 6 7 8{
replace temp_F`w'_q`i'=. if week>=53-`w' & (year==1914 | year==1939)
}
}
*DEFINE GLOBALS FOR BASELINE TEMPERATURE BINS (LAGS/LEADS)
foreach i of numlist 1 2 3 4 5{
global F`i' temp_F`i'_q1 temp_F`i'_q2 temp_F`i'_q3 o.temp_F`i'_q4 temp_F`i'_q5 temp_F`i'_q6 temp_F`i'_q7 temp_F`i'_q8 
}
foreach i of numlist 0 1 2 3 4 5 6 7{
global L`i' temp_L`i'_q1 temp_L`i'_q2 temp_L`i'_q3 o.temp_L`i'_q4 temp_L`i'_q5 temp_L`i'_q6 temp_L`i'_q7 temp_L`i'_q8
}

*CONSECUTIVE TEMPEARTURE SHOCKS
gen high_2weeks = ( (temp_L1_q8==1 | temp_L1_q7==1)  & (temp_L0_q8==1 | temp_L0_q7==1) ) 
gen high_3weeks = ( (temp_L2_q8==1 | temp_L2_q7==1) & (temp_L1_q8==1 | temp_L1_q7==1)  & (temp_L0_q8==1 | temp_L0_q7==1) ) 
gen high_4weeks = ( (temp_L4_q8==1 | temp_L3_q7==1) & (temp_L2_q8==1 | temp_L2_q7==1) & (temp_L1_q8==1 | temp_L1_q7==1)  & (temp_L0_q8==1 | temp_L0_q7==1) ) 

gen low_2weeks = ( (temp_L1_q1==1 | temp_L1_q2==1)  & (temp_L0_q1==1 | temp_L0_q2==1) ) 
gen low_3weeks = ( (temp_L2_q1==1 | temp_L2_q2==1) & (temp_L1_q2==1 | temp_L1_q1==1)  & (temp_L0_q1==1 | temp_L0_q2==1) ) 
gen low_4weeks = ( (temp_L3_q1==1 | temp_L3_q2==1) & (temp_L2_q1==1 | temp_L2_q2==1) & (temp_L1_q2==1 | temp_L1_q1==1)  & (temp_L0_q1==1 | temp_L0_q2==1) ) 


*CONSTRUCT AVERAGE LAG/CONTEMP EFFECTS AND INTERACTION WITH DECADE
local variable "q1 q2 q3 q5 q6 q7 q8"
foreach c of local variable {
gen tempL0_L7_`c'=0
replace tempL0_L7_`c'=1 if temp_L0_`c'==1 | temp_L1_`c'==1 | temp_L2_`c'==1 | temp_L3_`c'==1 | temp_L4_`c'==1 | temp_L5_`c'==1 | temp_L6_`c'==1 | temp_L7_`c'==1
replace tempL0_L7_`c'=. if year==1870 & week<8
}
local var "tempL0_L7_q1 tempL0_L7_q2 tempL0_L7_q3 tempL0_L7_q5 tempL0_L7_q6 tempL0_L7_q7 tempL0_L7_q8"
foreach c of local var {
foreach i of numlist 1 2 3 4 5 6 7{
gen `c'_decade`i'=0 if lninfantdeaths!=. & extreme_quantile!=.
replace `c'_decade`i'=`c' if decade_1==`i'
}
}
******************************************************************************


//CALCULATE ABSOLUTE HUMIDITY VARIABLES
gen tempC=(temperature-32)*(5/9)
gen Pws= 6.112*exp((17.62*tempC)/(tempC+243.12))
gen Psat=Pws*(1.0016+3.15*(10^-6)*(pressure*33.8639)-0.074*(pressure*33.8639)^-1)
gen Pi_hPa=(humidity*Psat)/100
gen ahum = 2.16679 * (Pi_hPa*100)/(273.15+tempC)
xtile ahum_quantile=ahum, nq(8)
*BIN DUMMIES
forvalues i = 1/8{
gen ahum_q`i'= 1 if ahum_quantile==`i'
replace ahum_q`i'=0 if ahum_q`i'==. 
} 

*LEAD/LAGS
foreach dist of numlist 1(1)5{
foreach i of numlist 1 2 3 5 6 7 8{
gen ahum_F`dist'_q`i'= ahum_q`i'[_n+`dist']
}
}
foreach dist of numlist 7(1)0{
foreach i of numlist 1 2 3 5 6 7 8{
gen ahum_L`dist'_q`i'= ahum_q`i'[_n-`dist']
}
}
*CONSTRUCT MISSING VALUES FOR BREAKS
foreach w of numlist 1(1)7{
foreach i of numlist 1 2 3 5 6 7 8{
replace ahum_L`w'_q`i'=. if week<=`w' & (year==1919 | year==1949)
}
}
foreach w of numlist 1(1)5{
foreach i of numlist 1 2 3 5 6 7 8{
replace ahum_F`w'_q`i'=. if week>=53-`w' & (year==1914 | year==1939)
}
}
*INTERACTIONS 
local variable "F5_q8 F4_q8 F3_q8 F2_q8 F1_q8 L0_q8 L1_q8 L2_q8 L3_q8 L4_q8 L5_q8 L6_q8 L7_q8"
foreach c of local variable {
gen inter_high_`c'=temp_`c'*ahum_`c'
}

//SAVE DATA FOR TABLES AND FIGURES
save "$root\intermediate_datasets\main_data.dta", replace
********************************************************************************



**********************************
** CONSTRUCT BY AGE DATA        **
**********************************
use "$root\intermediate_datasets\main_data", clear

drop if year<1870

sort year week
merge year week using "$root\raw_data\by_age_mortality_weekly_data"
tab _merge
keep if _merge==3
drop _merge


** Combined long age categories
gen age_young=age_5_20
replace age_young=age_5_25 if age_young==. & age_5_25!=.

gen age_adult=age_20_40
replace age_adult=age_20_45 if age_adult==. & age_20_45!=.
replace age_adult=age_25_45 if age_adult==. & age_25_45!=.

gen age_middle=age_40_60
replace age_middle=age_45_65 if age_middle==. & age_45_65!=.
replace age_middle=age_45_65 if age_middle==. & age_45_65!=.

gen age_elderly=age_60_plus
replace age_elderly=age_65_plus if age_elderly==. & age_65_plus!=.

replace children15=age_1_5 if children15==.

drop age_all age_0_1 age_1_5 age_5_20 age_5_25 age_20_40 age_20_45 age_25_45 age_40_60 age_45_65 age_45_65 age_60_plus age_65_plus


*Generate log death variables
foreach i in infants01 children15 age_young age_adult age_middle age_elderly {
gen ln`i'=ln(`i')
}

//SAVE DATA
save "$root\intermediate_datasets\by_age_data.dta", replace



**************************************
** CONSTRUCT CAUSE-OF-DEATH DATASET **
**************************************

//INLOAD CAUSE-OF-DEATH DATA
use "$root\raw_data\mortality_by_cause_weekly_data.dta", clear

//MERGE WITH OXFORD TEMPERATURE DATA 
merge m:1 year week using "$root\raw_data\oxford_temp_weekly_data.dta"
drop if _merge==2
drop _merge

//SETUP DISEASE-WEEK DATA
encode category, g(disease_nr)
egen disease_yr=group(disease_nr year)
tsset disease_yr week

//OUTCOME VARIABLE
gen ln_age_all=ln(age_all)

//TEMPERATURE VARIABLES
gen extreme_quantile=.
replace extreme_quantile=1 if oxford_min_temp<25
replace extreme_quantile=2 if oxford_min_temp>=25 & oxford_min_temp<30
replace extreme_quantile=3 if oxford_min_temp>=30 & oxford_min_temp<35
replace extreme_quantile=5 if oxford_max_temp>=65 & oxford_max_temp<70
replace extreme_quantile=6 if oxford_max_temp>=70 & oxford_max_temp<75
replace extreme_quantile=7 if oxford_max_temp>=75 & oxford_max_temp<80
replace extreme_quantile=8 if oxford_max_temp>=80

replace extreme_quantile=4 if extreme_quantile==. //COMPARISON BIN

*BINS
forvalues i = 1/8{
gen temp_q`i'= 1 if extreme_quantile==`i'
replace temp_q`i'=0 if temp_q`i'==. 
} 

*LEAD/LAGS FOR BINS 
foreach dist of numlist 1(1)5{
foreach i of numlist 1 2 3 4 5 6 7 8{
gen temp_F`dist'_q`i'= temp_q`i'[_n+`dist']
}
}
foreach dist of numlist 7(1)0{
foreach i of numlist 1 2 3 4 5 6 7 8{
gen temp_L`dist'_q`i'= temp_q`i'[_n-`dist']
}
}
*MISSING VALUES FOR BREAKS IN DATA 
foreach w of numlist 1(1)7{
foreach i of numlist 1 2 3 4 5 6 7 8{
replace temp_L`w'_q`i'=. if week<=`w' & (year==1919 | year==1949)
}
}
foreach w of numlist 1(1)5{
foreach i of numlist 1 2 3 4 5 6 7 8{
replace temp_F`w'_q`i'=. if week>=53-`w' & (year==1914 | year==1939)
}
}

local variable "q1 q2 q3 q5 q6 q7 q8"
foreach c of local variable {
gen tempL0_L7_`c'=0
replace tempL0_L7_`c'=1 if temp_L0_`c'==1 | temp_L1_`c'==1 | temp_L2_`c'==1 | temp_L3_`c'==1 | temp_L4_`c'==1 | temp_L5_`c'==1 | temp_L6_`c'==1 | temp_L7_`c'==1
replace tempL0_L7_`c'=. if year==1870 & week<8
}

local variable "q1 q2 q3 q5 q6 q7 q8"
foreach c of local variable {
gen tempF1_F5_`c'=0
replace tempF1_F5_`c'=1 if temp_F1_`c'==1 | temp_F2_`c'==1 | temp_F3_`c'==1 | temp_F4_`c'==1 | temp_F5_`c'==1 
replace tempF1_F5_`c'=. if year==1939 & week>37
}

//SAVE DATA FOR TABLES AND FIGURES
save "$root\intermediate_datasets\COD_data.dta", replace
********************************************************************************



****************************************
** CONSTRUCT DATA WITH LONDON TEMP    **
****************************************

//INLOAD MAIN DEATH DATA
use "$root\raw_data\aggregate_mortality_weekly_data.dta", clear 

//GENERATE OUTCOMES:
gen lntotaldeaths=ln(totaldeaths)
gen lninfantdeaths =ln(infants01)

//LONDON TEMPERATURE VARIABLE
gen temp_quantile=.
replace temp_quantile=1 if temperature<35
replace temp_quantile=2 if temperature>=35 & temperature<40
replace temp_quantile=3 if temperature>=40 & temperature<45
replace temp_quantile=4 if temperature>=45 & temperature<60
replace temp_quantile=5 if temperature>=60 & temperature<65
replace temp_quantile=6 if temperature>=65

replace temp_quantile=. if temperature>=45 & temperature<60 //COMPARISON BIN

*BINS
forvalues i = 1/6{
gen temp_q`i'= 1 if temp_quantile==`i'
replace temp_q`i'=0 if temp_q`i'==. 
} 

*LEAD/LAGS FOR BINS
foreach dist of numlist 1(1)5{
foreach i of numlist 1 2 3 4 5 6{
gen temp_F`dist'_q`i'= temp_q`i'[_n+`dist']
}
}
foreach dist of numlist 7(1)0{
foreach i of numlist 1 2 3 4 5 6{
gen temp_L`dist'_q`i'= temp_q`i'[_n-`dist']
}
}
*MISSING VALUES FOR BREAKS IN DATA 
foreach w of numlist 1(1)7{
foreach i of numlist 1 2 3 4 5 6{
replace temp_L`w'_q`i'=. if week<=`w' & (year==1919 | year==1949)
}
}
foreach w of numlist 1(1)5{
foreach i of numlist 1 2 3 4 5 6{
replace temp_F`w'_q`i'=. if week>=53-`w' & (year==1914 | year==1939)
}
}
//DEFINE GLOBALS
foreach i of numlist 1 2 3 4 5{
global F`i' temp_F`i'_q1 temp_F`i'_q2 temp_F`i'_q3 o.temp_F`i'_q4 o.temp_F`i'_q5 temp_F`i'_q6
}

foreach i of numlist 0 1 2 3 4 5 6 7{
global L`i' temp_L`i'_q1 temp_L`i'_q2 temp_L`i'_q3 o.temp_L`i'_q4 temp_L`i'_q5 temp_L`i'_q6
}


//SAVE DATA FOR TABLES AND FIGURES
save "$root\intermediate_datasets\londontemp_data.dta", replace
********************************************************************************


****************************************
** CONSTRUCT 1986-2001 MODERN DATASET **
****************************************


//INLOAD MODERN DATA
use "$root\raw_data\modern_mortality_weekly_data.dta", clear 

*CONVERT CELCIUS TO FAHRENHEIT
replace oxford_max_temp = oxford_max_temp*(9/5) + 32
replace oxford_min_temp = oxford_min_temp*(9/5) + 32

//TEMPERATURE VARIABLES
gen extreme_quantile=.
replace extreme_quantile=1 if oxford_min_temp<25
replace extreme_quantile=2 if oxford_min_temp>=25 & oxford_min_temp<30
replace extreme_quantile=3 if oxford_min_temp>=30 & oxford_min_temp<35

replace extreme_quantile=5 if oxford_max_temp>=65 & oxford_max_temp<70
replace extreme_quantile=6 if oxford_max_temp>=70 & oxford_max_temp<75
replace extreme_quantile=7 if oxford_max_temp>=75 & oxford_max_temp<80
replace extreme_quantile=8 if oxford_max_temp>=80

replace extreme_quantile=4 if extreme_quantile==.

*BINS
forvalues i = 1/8{
gen temp_q`i'= 1 if extreme_quantile==`i'
replace temp_q`i'=0 if temp_q`i'==. 
} 

*LEAD/LAGS FOR BINS
foreach dist of numlist 1(1)5{
foreach i of numlist 1 2 3 4 5 6 7 8{
gen temp_F`dist'_q`i'= temp_q`i'[_n+`dist']
}
}
foreach dist of numlist 7(1)0{
foreach i of numlist 1 2 3 4 5 6 7 8{
gen temp_L`dist'_q`i'= temp_q`i'[_n-`dist']
}
}

*DEFINE GLOBALS
foreach i of numlist 1 2 3 4 5{
global F`i' temp_F`i'_q1 temp_F`i'_q2 temp_F`i'_q3 o.temp_F`i'_q4 temp_F`i'_q5 temp_F`i'_q6 temp_F`i'_q7 temp_F`i'_q8 
}

foreach i of numlist 0 1 2 3 4 5 6 7{
global L`i' temp_L`i'_q1 temp_L`i'_q2 temp_L`i'_q3 o.temp_L`i'_q4 temp_L`i'_q5 temp_L`i'_q6 temp_L`i'_q7 temp_L`i'_q8
}

//OUTCOME
gen lntotaldeaths=ln(deaths)

//SAVE DATA FOR TABLES AND FIGURES
save "$root\intermediate_datasets\modern_data.dta", replace
********************************************************************************





****************************************
** CONSTRUCT SUB-DIGESTIVE DATASET    **
****************************************

//INLOAD DAYA WITH DIGESTIVE SUB-CATAGORIES 
use "$root\raw_data\subdigestive_mortality_weekly_data.dta", clear 

//MERGE WITH OXFORD TEMPERATURE DATA 
merge m:1 year week using "$root\raw_data\oxford_temp_weekly_data.dta"
drop if _merge==2
drop _merge

//SETUP DATA
encode new_cause, g(disease_nr)
egen disease_yr=group(disease_nr year)
tsset disease_yr week

//OUTCOME
gen ln_age_all=ln(age_all)

//TEMPERATURE VARIABLES
gen extreme_quantile=.
replace extreme_quantile=1 if oxford_min_temp<25
replace extreme_quantile=2 if oxford_min_temp>=25 & oxford_min_temp<30
replace extreme_quantile=3 if oxford_min_temp>=30 & oxford_min_temp<35

replace extreme_quantile=5 if oxford_max_temp>=65 & oxford_max_temp<70
replace extreme_quantile=6 if oxford_max_temp>=70 & oxford_max_temp<75
replace extreme_quantile=7 if oxford_max_temp>=75 & oxford_max_temp<80
replace extreme_quantile=8 if oxford_max_temp>=80

replace extreme_quantile=4 if extreme_quantile==.

*BINS
forvalues i = 1/8{
gen temp_q`i'= 1 if extreme_quantile==`i'
replace temp_q`i'=0 if temp_q`i'==. 
} 

*LEAD/LAGS FOR BINS
foreach dist of numlist 1(1)5{
foreach i of numlist 1 2 3 4 5 6 7 8{
gen temp_F`dist'_q`i'= temp_q`i'[_n+`dist']
}
}
foreach dist of numlist 7(1)0{
foreach i of numlist 1 2 3 4 5 6 7 8{
gen temp_L`dist'_q`i'= temp_q`i'[_n-`dist']
}
}

*MISSING VALUES FOR BREAKS IN DATA 
foreach w of numlist 1(1)7{
foreach i of numlist 1 2 3 4 5 6 7 8{
replace temp_L`w'_q`i'=. if week<=`w' & year==1919
}
}
//LEADS
foreach w of numlist 1(1)5{
foreach i of numlist 1 2 3 4 5 6 7 8{
replace temp_F`w'_q`i'=. if week>=53-`w' & year==1914 
}
}
//DEFINE GLOBALS
foreach i of numlist 1 2 3 4 5{
global F`i' temp_F`i'_q1 temp_F`i'_q2 temp_F`i'_q3 o.temp_F`i'_q4 temp_F`i'_q5 temp_F`i'_q6 temp_F`i'_q7 temp_F`i'_q8 
}

foreach i of numlist 0 1 2 3 4 5 6 7{
global L`i' temp_L`i'_q1 temp_L`i'_q2 temp_L`i'_q3 o.temp_L`i'_q4 temp_L`i'_q5 temp_L`i'_q6 temp_L`i'_q7 temp_L`i'_q8
}

//SAVE DATA FOR TABLES AND FIGURES
save "$root\intermediate_datasets\subdigestive_data.dta", replace
********************************************************************************











