//INLOAD MODERNE DATA (constructed in "combine_datasets.do")
use "$root\intermediate_datasets\modern_data.dta", clear 

//SET OUTPUT FOLDER
cd "$root\results\appendix_figure11"

//DEFINE GLOBALS FOR BASELINE TEMPERATURE BINS (LAGS/LEADS)
foreach i of numlist 1 2 3 4 5{
global F`i' temp_F`i'_q1 temp_F`i'_q2 temp_F`i'_q3 o.temp_F`i'_q4 temp_F`i'_q5 temp_F`i'_q6 temp_F`i'_q7 temp_F`i'_q8 
}
foreach i of numlist 0 1 2 3 4 5 6 7{
global L`i' temp_L`i'_q1 temp_L`i'_q2 temp_L`i'_q3 o.temp_L`i'_q4 temp_L`i'_q5 temp_L`i'_q6 temp_L`i'_q7 temp_L`i'_q8
}


//APPENDIX FIGURE A.11: TOTAL MORTALITY RESULTS FOR THE MODERN PERIOD (1981-2006)
xi: reghdfe lntotaldeaths $F1 $F2 $F3 $F4 $F5 $L7 $L6 $L5 $L4 $L3 $L2 $L1 $L0 , absorb(year week) vce(r)
estimates store modern_period

coefplot (modern_period,  mfcolor(white)  mc(black) msymbol(triangle) lcolor(black)  lwidth(thick) recast(connected) ciopts(lpattern(shortdash) lwidth(thin) lcolor(black))   ), title("First lead", color(black) size(large)) vertical omitted  yline(0) keep(temp_F1*) rename(temp_F1_* = "") graphregion(fcolor(white)) ylabel(-0.05 0.00 0.05 0.1 0.15 .2) scale(1.4) xlabel(1 "25<"  2 "25-30" 3 "30-35" 4 "35-65" 5 "65-70" 6 "70-75" 7 "75-80" 8 ">80" ) ylabel(,angle(0) ) legend(size(vsmall) symysize(vsmall) symxsize(vsmall)) legend(off)
graph save Graph "temp_F1", replace
coefplot (modern_period,  mfcolor(white)  mc(black) msymbol(triangle) lcolor(black)  lwidth(thick) recast(connected) ciopts(lpattern(shortdash) lwidth(thin) lcolor(black))   ), title("Contemporaneous effect", color(black) size(large)) vertical omitted  yline(0) keep(temp_L0*) rename(temp_L0_* = "") graphregion(fcolor(white)) ylabel(-0.05 0.00 0.05 0.1 0.15 .2) scale(1.4) xlabel(1 "25<"  2 "25-30" 3 "30-35" 4 "35-65" 5 "65-70" 6 "70-75" 7 "75-80" 8 ">80" ) ylabel(,angle(0) ) legend(size(vsmall) symysize(vsmall) symxsize(vsmall)) legend(off)
graph save Graph "temp_L0", replace
coefplot (modern_period,  mfcolor(white)  mc(black) msymbol(triangle) lcolor(black)  lwidth(thick) recast(connected) ciopts(lpattern(shortdash) lwidth(thin) lcolor(black))   ), title("First lag", color(black) size(large)) vertical omitted  yline(0) keep(temp_L1*) rename(temp_L1_* = "") graphregion(fcolor(white)) ylabel(-0.05 0.00 0.05 0.1 0.15 .2) scale(1.4) xlabel(1 "25<"  2 "25-30" 3 "30-35" 4 "35-65" 5 "65-70" 6 "70-75" 7 "75-80" 8 ">80" ) ylabel(,angle(0) ) legend(size(vsmall) symysize(vsmall) symxsize(vsmall)) legend(off)
graph save Graph "temp_L1", replace
coefplot (modern_period,  mfcolor(white)  mc(black) msymbol(triangle) lcolor(black)  lwidth(thick) recast(connected) ciopts(lpattern(shortdash) lwidth(thin) lcolor(black))   ), title("Second lag", color(black) size(large)) vertical omitted  yline(0) keep(temp_L2*) rename(temp_L2_* = "") graphregion(fcolor(white)) ylabel(-0.05 0.00 0.05 0.1 0.15 .2) scale(1.4) xlabel(1 "25<"  2 "25-30" 3 "30-35" 4 "35-65" 5 "65-70" 6 "70-75" 7 "75-80" 8 ">80" ) ylabel(,angle(0) ) legend(size(vsmall) symysize(vsmall) symxsize(vsmall)) legend(off)
graph save Graph "temp_L2", replace
coefplot (modern_period,  mfcolor(white)  mc(black) msymbol(triangle) lcolor(black)  lwidth(thick) recast(connected) ciopts(lpattern(shortdash) lwidth(thin) lcolor(black))   ), title("Third lag", color(black) size(large)) vertical omitted  yline(0) keep(temp_L3*) rename(temp_L3_* = "") graphregion(fcolor(white)) ylabel(-0.05 0.00 0.05 0.1 0.15 .2) scale(1.4) xlabel(1 "25<"  2 "25-30" 3 "30-35" 4 "35-65" 5 "65-70" 6 "70-75" 7 "75-80" 8 ">80" ) ylabel(,angle(0) ) legend(size(vsmall) symysize(vsmall) symxsize(vsmall)) legend(off)
graph save Graph "temp_L3", replace
coefplot (modern_period,  mfcolor(white)  mc(black) msymbol(triangle) lcolor(black)  lwidth(thick) recast(connected) ciopts(lpattern(shortdash) lwidth(thin) lcolor(black))   ), title("Fourth lag", color(black) size(large)) vertical omitted  yline(0) keep(temp_L4*) rename(temp_L4_* = "") graphregion(fcolor(white)) ylabel(-0.05 0.00 0.05 0.1 0.15 .2) scale(1.4) xlabel(1 "25<"  2 "25-30" 3 "30-35" 4 "35-65" 5 "65-70" 6 "70-75" 7 "75-80" 8 ">80" ) ylabel(,angle(0) ) legend(size(vsmall) symysize(vsmall) symxsize(vsmall)) legend(off)
graph save Graph "temp_L4", replace


gr combine temp_F1.gph temp_L0.gph temp_L1.gph temp_L2.gph temp_L3.gph temp_L4.gph,   ycom altshrink graphregion(fcolor(white)) rows(4)  cols(2) 
graph save Graph "Figure11A", replace
graph export "Figure11A.pdf", replace as(pdf)

local variable "temp_F1 temp_L0 temp_L1 temp_L2 temp_L3 temp_L4"
foreach c of local variable {
erase "`c'.gph"
}
