//INLOAD MAIN DATA (constructed in "combine_datasets.do")
use "$root\intermediate_datasets\main_data.dta", clear 

//SET OUTPUT FOLDER
cd "$root\results\appendix_figure13"

//DEFINE GLOBALS FOR BASELINE TEMPERATURE BINS (LAGS/LEADS)
foreach i of numlist 1 2 3 4 5{
global F`i' temp_F`i'_q1 temp_F`i'_q2 temp_F`i'_q3 o.temp_F`i'_q4 temp_F`i'_q5 temp_F`i'_q6 temp_F`i'_q7 temp_F`i'_q8 
}
foreach i of numlist 0 1 2 3 4 5 6 7{
global L`i' temp_L`i'_q1 temp_L`i'_q2 temp_L`i'_q3 o.temp_L`i'_q4 temp_L`i'_q5 temp_L`i'_q6 temp_L`i'_q7 temp_L`i'_q8
}

xi: reghdfe lntotaldeaths $F1 $F2 $F3 $F4 $F5 $L7 $L6 $L5 $L4 $L3 $L2 $L1 $L0 ahum_F1_q1 - ahum_L0_q8 inter_high_F5_q8 - inter_high_L7_q8 rainfall thickfog_report if year<=1914, absorb(year week)  vce(r)
estimates store pre1914
xi: reghdfe lntotaldeaths $F1 $F2 $F3 $F4 $F5 $L7 $L6 $L5 $L4 $L3 $L2 $L1 $L0 ahum_F1_q1 - ahum_L0_q8 inter_high_F5_q8 - inter_high_L7_q8  rainfall thickfog_report if year>=1919, absorb(year week) vce(r)
estimates store post1919

//APPENDIX FIGURE A.13: HUMIDITY AND TOTAL MORTALITY BEFORE AND AFTER WWI CONTROLLING FOR A FULL SET OF LEADS/LAGS OF TEMPERATURE
coefplot (pre1914,  mfcolor(white)  mc(black) msymbol(triangle) lcolor(black)  lwidth(thick) recast(connected) ciopts(lpattern(shortdash) lwidth(thin) lcolor(black))   ) (post1919, msymbol(diamond) mfcolor(white) mc(gs8) lpattern(dash) lcolor(gs8) lwidth(thick) recast(connected) ciopts(lpattern(shortdash) lwidth(thin) lcolor(gs8))  ), title("First lead", color(black) size(large)) vertical omitted  yline(0) keep(ahum_F1*) rename(ahum_F1_* = "") graphregion(fcolor(white)) ylabel(-0.05 0.00 0.05 0.1 0.15 .2) scale(1.4) legend(size(vsmall) symysize(vsmall) symxsize(vsmall))
graph save Graph "ahum_F1", replace
coefplot (pre1914,  mfcolor(white)  mc(black) msymbol(triangle) lcolor(black)  lwidth(thick) recast(connected) ciopts(lpattern(shortdash) lwidth(thin) lcolor(black))   ) (post1919, msymbol(diamond) mfcolor(white) mc(gs8) lpattern(dash) lcolor(gs8) lwidth(thick) recast(connected) ciopts(lpattern(shortdash) lwidth(thin) lcolor(gs8))  ), title("Contemporaneous effect", color(black) size(large)) vertical omitted  yline(0) keep(ahum_L0*) rename(ahum_L0_* = "") graphregion(fcolor(white)) ylabel(-0.05 0.00 0.05 0.1 0.15 .2) scale(1.4) legend(size(vsmall) symysize(vsmall) symxsize(vsmall))
graph save Graph "ahum_L0", replace
coefplot (pre1914,  mfcolor(white)  mc(black) msymbol(triangle) lcolor(black)  lwidth(thick) recast(connected) ciopts(lpattern(shortdash) lwidth(thin) lcolor(black))   ) (post1919, msymbol(diamond) mfcolor(white) mc(gs8) lpattern(dash) lcolor(gs8) lwidth(thick) recast(connected) ciopts(lpattern(shortdash) lwidth(thin) lcolor(gs8))  ), title("First lag", color(black) size(large)) vertical omitted  yline(0) keep(ahum_L1*) rename(ahum_L1_* = "") graphregion(fcolor(white)) ylabel(-0.05 0.00 0.05 0.1 0.15 .2) scale(1.4) legend(size(vsmall) symysize(vsmall) symxsize(vsmall))
graph save Graph "ahum_L1", replace
coefplot (pre1914,  mfcolor(white)  mc(black) msymbol(triangle) lcolor(black)  lwidth(thick) recast(connected) ciopts(lpattern(shortdash) lwidth(thin) lcolor(black))   ) (post1919, msymbol(diamond) mfcolor(white) mc(gs8) lpattern(dash) lcolor(gs8) lwidth(thick) recast(connected) ciopts(lpattern(shortdash) lwidth(thin) lcolor(gs8))  ), title("Second lag", color(black) size(large)) vertical omitted  yline(0) keep(ahum_L2*) rename(ahum_L2_* = "") graphregion(fcolor(white)) ylabel(-0.05 0.00 0.05 0.1 0.15 .2) scale(1.4) legend(size(vsmall) symysize(vsmall) symxsize(vsmall))
graph save Graph "ahum_L2", replace
coefplot (pre1914,  mfcolor(white)  mc(black) msymbol(triangle) lcolor(black)  lwidth(thick) recast(connected) ciopts(lpattern(shortdash) lwidth(thin) lcolor(black))   ) (post1919, msymbol(diamond) mfcolor(white) mc(gs8) lpattern(dash) lcolor(gs8) lwidth(thick) recast(connected) ciopts(lpattern(shortdash) lwidth(thin) lcolor(gs8))  ), title("Third lag", color(black) size(large)) vertical omitted  yline(0) keep(ahum_L3*) rename(ahum_L3_* = "") graphregion(fcolor(white)) ylabel(-0.05 0.00 0.05 0.1 0.15 .2) scale(1.4) legend(size(vsmall) symysize(vsmall) symxsize(vsmall))
graph save Graph "ahum_L3", replace
coefplot (pre1914,  mfcolor(white)  mc(black) msymbol(triangle) lcolor(black)  lwidth(thick) recast(connected) ciopts(lpattern(shortdash) lwidth(thin) lcolor(black))   ) (post1919, msymbol(diamond) mfcolor(white) mc(gs8) lpattern(dash) lcolor(gs8) lwidth(thick) recast(connected) ciopts(lpattern(shortdash) lwidth(thin) lcolor(gs8))  ), title("Fourth lag", color(black) size(large)) vertical omitted  yline(0) keep(ahum_L4*) rename(ahum_L4_* = "") graphregion(fcolor(white)) ylabel(-0.05 0.00 0.05 0.1 0.15 .2) scale(1.4) legend(size(vsmall) symysize(vsmall) symxsize(vsmall))
graph save Graph "ahum_L4", replace

grc1leg ahum_F1.gph ahum_L0.gph ahum_L1.gph ahum_L2.gph ahum_L3.gph ahum_L4.gph, ycom altshrink graphregion(fcolor(white)) rows(4)  cols(2)
graph save Graph "Figure13A", replace
graph export "Figure13A.pdf", replace as(pdf)

local variable "ahum_F1 ahum_L0 ahum_L1 ahum_L2 ahum_L3 ahum_L4"
foreach c of local variable {
erase "`c'.gph"
}
