//INLOAD MAIN DATA (constructed in "combine_datasets.do")
use "$root\intermediate_datasets\main_data.dta", clear 

//SET OUTPUT FOLDER
cd "$root\results\appendix_figure14"

//DEFINE GLOBALS FOR BASELINE TEMPERATURE BINS (LAGS/LEADS)
foreach i of numlist 1 2 3 4 5{
global F`i' temp_F`i'_q1 temp_F`i'_q2 temp_F`i'_q3 o.temp_F`i'_q4 temp_F`i'_q5 temp_F`i'_q6 temp_F`i'_q7 temp_F`i'_q8 
}
foreach i of numlist 0 1 2 3 4 5 6 7{
global L`i' temp_L`i'_q1 temp_L`i'_q2 temp_L`i'_q3 o.temp_L`i'_q4 temp_L`i'_q5 temp_L`i'_q6 temp_L`i'_q7 temp_L`i'_q8
}

//APPENDIX FIGURE A.14: ADDITIONAL LEADS AND LAGS FROM THE INFANT MORTALITY REGRESSIONS
xi: reghdfe lninfantdeaths $F1 $F2 $F3 $F4 $F5 $L7 $L6 $L5 $L4 $L3 $L2 $L1 $L0  rainfall thickfog_report if  year<=1914, absorb(year week) vce(r)
estimates store pre1914
xi: reghdfe lninfantdeaths $F1 $F2 $F3 $F4 $F5 $L7 $L6 $L5 $L4 $L3 $L2 $L1 $L0  rainfall thickfog_report if year>=1919, absorb(year wee) vce(r)
estimates store post1919

coefplot (pre1914,  mfcolor(white)  mc(black) msymbol(triangle) lcolor(black)  lwidth(thick) recast(connected) ciopts(lpattern(shortdash) lwidth(thin) lcolor(black))   ) (post1919, msymbol(diamond) mfcolor(white) mc(gs8) lpattern(dash) lcolor(gs8) lwidth(thick) recast(connected) ciopts(lpattern(shortdash) lwidth(thin) lcolor(gs8))  ), title("Second lead", color(black) size(medium)) vertical omitted  yline(0) keep(temp_F2*) rename(temp_F2_* = "") graphregion(fcolor(white)) ylabel(-0.1 -0.05 0.00 0.05 0.1 0.15 0.2 0.25) scale(1.4) xlabel(1 "25<"  2 "25-30" 3 "30-35" 4 "35-65" 5 "65-70" 6 "70-75" 7 "75-80" 8 ">80" ) ylabel(,angle(0) ) legend(size(vsmall) symysize(vsmall) symxsize(vsmall))
graph save Graph "temp_F2", replace
coefplot (pre1914,  mfcolor(white)  mc(black) msymbol(triangle) lcolor(black)  lwidth(thick) recast(connected) ciopts(lpattern(shortdash) lwidth(thin) lcolor(black))   ) (post1919, msymbol(diamond) mfcolor(white) mc(gs8) lpattern(dash) lcolor(gs8) lwidth(thick) recast(connected) ciopts(lpattern(shortdash) lwidth(thin) lcolor(gs8))  ), title("Third lead", color(black) size(medium)) vertical omitted  yline(0) keep(temp_F3*) rename(temp_F3_* = "") graphregion(fcolor(white)) ylabel(-0.1 -0.05 0.00 0.05 0.1 0.15 0.2 0.25) scale(1.4) xlabel(1 "25<"  2 "25-30" 3 "30-35" 4 "35-65" 5 "65-70" 6 "70-75" 7 "75-80" 8 ">80" ) ylabel(,angle(0) ) legend(size(vsmall) symysize(vsmall) symxsize(vsmall))
graph save Graph "temp_F3", replace
coefplot (pre1914,  mfcolor(white)  mc(black) msymbol(triangle) lcolor(black)  lwidth(thick) recast(connected) ciopts(lpattern(shortdash) lwidth(thin) lcolor(black))   ) (post1919, msymbol(diamond) mfcolor(white) mc(gs8) lpattern(dash) lcolor(gs8) lwidth(thick) recast(connected) ciopts(lpattern(shortdash) lwidth(thin) lcolor(gs8))  ), title("Fourth lead", color(black) size(medium)) vertical omitted  yline(0) keep(temp_F4*) rename(temp_F4_* = "") graphregion(fcolor(white)) ylabel(-0.1 -0.05 0.00 0.05 0.1 0.15 0.2 0.25) scale(1.4) xlabel(1 "25<"  2 "25-30" 3 "30-35" 4 "35-65" 5 "65-70" 6 "70-75" 7 "75-80" 8 ">80" ) ylabel(,angle(0) ) legend(size(vsmall) symysize(vsmall) symxsize(vsmall))
graph save Graph "temp_F4", replace
coefplot (pre1914,  mfcolor(white)  mc(black) msymbol(triangle) lcolor(black)  lwidth(thick) recast(connected) ciopts(lpattern(shortdash) lwidth(thin) lcolor(black))   ) (post1919, msymbol(diamond) mfcolor(white) mc(gs8) lpattern(dash) lcolor(gs8) lwidth(thick) recast(connected) ciopts(lpattern(shortdash) lwidth(thin) lcolor(gs8))  ), title("Fifth lead", color(black) size(medium)) vertical omitted  yline(0) keep(temp_F5*) rename(temp_F5_* = "") graphregion(fcolor(white)) ylabel(-0.1 -0.05 0.00 0.05 0.1 0.15 0.2 0.25) scale(1.4) xlabel(1 "25<"  2 "25-30" 3 "30-35" 4 "35-65" 5 "65-70" 6 "70-75" 7 "75-80" 8 ">80" ) ylabel(,angle(0) ) legend(size(vsmall) symysize(vsmall) symxsize(vsmall))
graph save Graph "temp_F5", replace
coefplot (pre1914,  mfcolor(white)  mc(black) msymbol(triangle) lcolor(black)  lwidth(thick) recast(connected) ciopts(lpattern(shortdash) lwidth(thin) lcolor(black))   ) (post1919, msymbol(diamond) mfcolor(white) mc(gs8) lpattern(dash) lcolor(gs8) lwidth(thick) recast(connected) ciopts(lpattern(shortdash) lwidth(thin) lcolor(gs8))  ), title("Fifth lag", color(black) size(medium)) vertical omitted  yline(0) keep(temp_L5*) rename(temp_L5_* = "") graphregion(fcolor(white)) ylabel(-0.1 -0.05 0.00 0.05 0.1 0.15 0.2 0.25) scale(1.4) xlabel(1 "25<"  2 "25-30" 3 "30-35" 4 "35-65" 5 "65-70" 6 "70-75" 7 "75-80" 8 ">80" ) ylabel(,angle(0) ) legend(size(vsmall) symysize(vsmall) symxsize(vsmall))
graph save Graph "temp_L5", replace
coefplot (pre1914,  mfcolor(white)  mc(black) msymbol(triangle) lcolor(black)  lwidth(thick) recast(connected) ciopts(lpattern(shortdash) lwidth(thin) lcolor(black))   ) (post1919, msymbol(diamond) mfcolor(white) mc(gs8) lpattern(dash) lcolor(gs8) lwidth(thick) recast(connected) ciopts(lpattern(shortdash) lwidth(thin) lcolor(gs8))  ), title("Sixth lag", color(black) size(medium)) vertical omitted  yline(0) keep(temp_L6*) rename(temp_L6_* = "") graphregion(fcolor(white)) ylabel(-0.1 -0.05 0.00 0.05 0.1 0.15 0.2 0.25) scale(1.4) xlabel(1 "25<"  2 "25-30" 3 "30-35" 4 "35-65" 5 "65-70" 6 "70-75" 7 "75-80" 8 ">80" ) ylabel(,angle(0) ) legend(size(vsmall) symysize(vsmall) symxsize(vsmall))
graph save Graph "temp_L6", replace
coefplot (pre1914,  mfcolor(white)  mc(black) msymbol(triangle) lcolor(black)  lwidth(thick) recast(connected) ciopts(lpattern(shortdash) lwidth(thin) lcolor(black))   ) (post1919, msymbol(diamond) mfcolor(white) mc(gs8) lpattern(dash) lcolor(gs8) lwidth(thick) recast(connected) ciopts(lpattern(shortdash) lwidth(thin) lcolor(gs8))  ), title("Seventh lag", color(black) size(medium)) vertical omitted  yline(0) keep(temp_L7*) rename(temp_L7_* = "") graphregion(fcolor(white)) ylabel(-0.1 -0.05 0.00 0.05 0.1 0.15 0.2 0.25) scale(1.4) xlabel(1 "25<"  2 "25-30" 3 "30-35" 4 "35-65" 5 "65-70" 6 "70-75" 7 "75-80" 8 ">80" ) ylabel(,angle(0) ) legend(size(vsmall) symysize(vsmall) symxsize(vsmall))
graph save Graph "temp_L7", replace

grc1leg temp_F5.gph temp_F4.gph temp_F3.gph temp_F2.gph temp_L5.gph temp_L6.gph temp_L7.gph, graphregion(fcolor(white)) altshrink ycom
graph save Graph "Figure14A", replace
graph export "Figure14A.pdf", replace as(pdf)

local variable "temp_F2 temp_F3 temp_F4 temp_F5 temp_L5 temp_L6 temp_L7"
foreach c of local variable {
erase "`c'.gph"
}

