//INLOAD DATA BASED ON LONDON TEMPERATURES (constructed in "combine_datasets.do")
use "$root\intermediate_datasets\londontemp_data.dta", clear 

//SET OUTPUT FOLDER
cd "$root\results\appendix_figure16"

//DEFINE GLOBALS
foreach i of numlist 1 2 3 4 5{
global F`i' temp_F`i'_q1 temp_F`i'_q2 temp_F`i'_q3 o.temp_F`i'_q4 o.temp_F`i'_q5 temp_F`i'_q6
}
foreach i of numlist 0 1 2 3 4 5 6 7{
global L`i' temp_L`i'_q1 temp_L`i'_q2 temp_L`i'_q3 o.temp_L`i'_q4 temp_L`i'_q5 temp_L`i'_q6
}

//APPENDIX FIGURE A.16: INFANT MORTALITY RESULTS USING MEAN WEEKLY TEMPERATURE MEASURED IN LONDON
xi: reghdfe lninfantdeaths $F1 $F2 $F3 $F4 $F5 $L7 $L6 $L5 $L4 $L3 $L2 $L1 $L0  rainfall thickfog_report if  year<=1914, absorb(year week) vce(r)
estimates store pre1914
xi: reghdfe lninfantdeaths $F1 $F2 $F3 $F4 $F5 $L7 $L6 $L5 $L4 $L3 $L2 $L1 $L0  rainfall thickfog_report if year>=1919, absorb(year week) vce(r)
estimates store post1919

coefplot (pre1914,  mfcolor(white)  mc(black) msymbol(triangle) lcolor(black)  lwidth(thick) recast(connected) ciopts(lpattern(shortdash) lwidth(thin) lcolor(black))   ) (post1919, msymbol(diamond) mfcolor(white) mc(gs8) lpattern(dash) lcolor(gs8) lwidth(thick) recast(connected) ciopts(lpattern(shortdash) lwidth(thin) lcolor(gs8))  ), title("First lead", color(black) size(large)) vertical omitted  yline(0) keep(temp_F1*) rename(temp_F1_* = "") graphregion(fcolor(white)) ylabel(-0.2 -0.1 0.00 0.1 0.2 0.3 0.4) scale(1.4) xlabel(1 "35<"  2 "35-40" 3 "40-45" 4 "45-60"  5 "60-65" 6 ">65" )  ylabel(,angle(0) ) legend(size(vsmall) symysize(vsmall) symxsize(vsmall))
graph save Graph "temp_F1", replace
coefplot (pre1914,  mfcolor(white)  mc(black) msymbol(triangle) lcolor(black)  lwidth(thick) recast(connected) ciopts(lpattern(shortdash) lwidth(thin) lcolor(black))   ) (post1919, msymbol(diamond) mfcolor(white) mc(gs8) lpattern(dash) lcolor(gs8) lwidth(thick) recast(connected) ciopts(lpattern(shortdash) lwidth(thin) lcolor(gs8))  ), title("Contemporaneous effect", color(black) size(large)) vertical omitted  yline(0) keep(temp_L0*) rename(temp_L0_* = "") graphregion(fcolor(white)) ylabel(-0.2 -0.1 0.00 0.1 0.2 0.3 0.4) scale(1.4) xlabel(1 "35<"  2 "35-40" 3 "40-45" 4 "45-60"  5 "60-65" 6 ">65" ) ylabel(,angle(0) ) legend(size(vsmall) symysize(vsmall) symxsize(vsmall))
graph save Graph "temp_L0", replace
coefplot (pre1914,  mfcolor(white)  mc(black) msymbol(triangle) lcolor(black)  lwidth(thick) recast(connected) ciopts(lpattern(shortdash) lwidth(thin) lcolor(black))   ) (post1919, msymbol(diamond) mfcolor(white) mc(gs8) lpattern(dash) lcolor(gs8) lwidth(thick) recast(connected) ciopts(lpattern(shortdash) lwidth(thin) lcolor(gs8))  ), title("First lag", color(black) size(large)) vertical omitted  yline(0) keep(temp_L1*) rename(temp_L1_* = "") graphregion(fcolor(white)) ylabel(-0.2 -0.1 0.00 0.1 0.2 0.3 0.4) scale(1.4) xlabel(1 "35<"  2 "35-40" 3 "40-45" 4 "45-60"  5 "60-65" 6 ">65" ) ylabel(,angle(0) ) legend(size(vsmall) symysize(vsmall) symxsize(vsmall))
graph save Graph "temp_L1", replace
coefplot (pre1914,  mfcolor(white)  mc(black) msymbol(triangle) lcolor(black)  lwidth(thick) recast(connected) ciopts(lpattern(shortdash) lwidth(thin) lcolor(black))   ) (post1919, msymbol(diamond) mfcolor(white) mc(gs8) lpattern(dash) lcolor(gs8) lwidth(thick) recast(connected) ciopts(lpattern(shortdash) lwidth(thin) lcolor(gs8))  ), title("Second lag", color(black) size(large)) vertical omitted  yline(0) keep(temp_L2*) rename(temp_L2_* = "") graphregion(fcolor(white)) ylabel(-0.2 -0.1 0.00 0.1 0.2 0.3 0.4) scale(1.4) xlabel(1 "35<"  2 "35-40" 3 "40-45" 4 "45-60"  5 "60-65" 6 ">65" ) ylabel(,angle(0) ) legend(size(vsmall) symysize(vsmall) symxsize(vsmall))
graph save Graph "temp_L2", replace
coefplot (pre1914,  mfcolor(white)  mc(black) msymbol(triangle) lcolor(black)  lwidth(thick) recast(connected) ciopts(lpattern(shortdash) lwidth(thin) lcolor(black))   ) (post1919, msymbol(diamond) mfcolor(white) mc(gs8) lpattern(dash) lcolor(gs8) lwidth(thick) recast(connected) ciopts(lpattern(shortdash) lwidth(thin) lcolor(gs8))  ), title("Third lag", color(black) size(large)) vertical omitted  yline(0) keep(temp_L3*) rename(temp_L3_* = "") graphregion(fcolor(white)) ylabel(-0.2 -0.1 0.00 0.1 0.2 0.3 0.4) scale(1.4) xlabel(1 "35<"  2 "35-40" 3 "40-45" 4 "45-60"  5 "60-65" 6 ">65" ) ylabel(,angle(0) ) legend(size(vsmall) symysize(vsmall) symxsize(vsmall))
graph save Graph "temp_L3", replace
coefplot (pre1914,  mfcolor(white)  mc(black) msymbol(triangle) lcolor(black)  lwidth(thick) recast(connected) ciopts(lpattern(shortdash) lwidth(thin) lcolor(black))   ) (post1919, msymbol(diamond) mfcolor(white) mc(gs8) lpattern(dash) lcolor(gs8) lwidth(thick) recast(connected) ciopts(lpattern(shortdash) lwidth(thin) lcolor(gs8))  ), title("Fourth lag", color(black) size(large)) vertical omitted  yline(0) keep(temp_L4*) rename(temp_L4_* = "") graphregion(fcolor(white)) ylabel(-0.2 -0.1 0.00 0.1 0.2 0.3 0.4) scale(1.4) xlabel(1 "35<"  2 "35-40" 3 "40-45" 4 "45-60"  5 "60-65" 6 ">65" ) ylabel(,angle(0) ) legend(size(vsmall) symysize(vsmall) symxsize(vsmall))
graph save Graph "temp_L4", replace

grc1leg temp_F1.gph temp_L0.gph temp_L1.gph temp_L2.gph temp_L3.gph temp_L4.gph, graphregion(fcolor(white)) altshrink ycom  rows(4)  cols(2)
graph save Graph "Figure16A", replace
graph export "Figure16A.pdf", replace as(pdf)


local variable "temp_F1 temp_L0 temp_L1 temp_L2 temp_L3 temp_L4"
foreach c of local variable {
erase "`c'.gph"
}

