//INLOAD MAIN DATA (constructed in "combine_datasets.do")
use "$root\intermediate_datasets\main_data.dta", clear 

//SET OUTPUT FOLDER
cd "$root\results\figure_1"

//FIGURE 1: INFANT DEATHS PER 100 NON-INFANT DEATHS, DIGESTIVE DEATHS PER 100 NON-DIGESTIVE DEATHS, AND WARM-WEEK EFFECTS BY PERIODS
preserve
*PANEL A
foreach i of numlist 1 2 3 4 5 6 7{
xi: reghdfe infant_ratio tempL0_L7_q1_decade`i' tempL0_L7_q2_decade`i' tempL0_L7_q3_decade`i' tempL0_L7_q5_decade`i' tempL0_L7_q6_decade`i' tempL0_L7_q8_decade`i'  rainfall thickfog_report if decade_1==`i', absorb(year week) vce(r)
mat beta=e(b)
svmat double beta, names(matcol)
egen test_L0L7_q8_decade`i'=max(betatempL0_L7_q8_decade`i')
drop betatempL0_L7_q1_decade`i' betatempL0_L7_q2_decade`i' betatempL0_L7_q3_decade`i' betatempL0_L7_q5_decade`i' betatempL0_L7_q6_decade`i' betatempL0_L7_q8_decade`i' betarainfall betathickfog_report beta_cons

}

gen coeff_L0L7_q8=test_L0L7_q8_decade1 if year>=1873 & year<=1879
replace coeff_L0L7_q8=test_L0L7_q8_decade2 if year>=1880 & year<=1889
replace coeff_L0L7_q8=test_L0L7_q8_decade3 if year>=1890 & year<=1899
replace coeff_L0L7_q8=test_L0L7_q8_decade4 if year>=1900 & year<=1914
replace coeff_L0L7_q8=test_L0L7_q8_decade5 if year>=1919 & year<=1929
replace coeff_L0L7_q8=test_L0L7_q8_decade6 if year>=1930 & year<=1939
replace coeff_L0L7_q8=test_L0L7_q8_decade7 if year>=1949 & year<=1965
drop test_L0L7*

tsset date
twoway (tsline infant_ratio if year<=1914, graphregion(fcolor(white)) lc(gs10) yaxis(1) title("Panel A", color(black) size(medium)) xtitle("Week") ytitle("Infant deaths per 100 non-infant deaths") )  (scatter coeff_L0L7_q8 date if year<=1914, graphregion(fcolor(white)) legend(off) yaxis(2) msymbol(D) mc(black) mfc(gs16) ytitle("Regression coefficient size", axis(2)) ) || /// 
(tsline infant_ratio if year>=1919 & year<1940, graphregion(fcolor(white)) lc(gs10) yaxis(1) ) (scatter coeff_L0L7_q8 date if year>=1919 & year<1940, graphregion(fcolor(white)) yaxis(2) msymbol(D) mc(black) mfc(gs16) ) || ///
(tsline infant_ratio if year>=1949, graphregion(fcolor(white)) lc(gs10) yaxis(1) ) (scatter coeff_L0L7_q8 date if year>=1949, graphregion(fcolor(white)) yaxis(2) msymbol(D) mc(black) mfc(gs16) ) 
graph save Graph "Figure1_panelA", replace
restore 


preserve
*PANEL B:
foreach i of numlist 1 2 3 4 5 6 7{
xi: reghdfe digestive_ratio tempL0_L7_q1_decade`i' tempL0_L7_q2_decade`i' tempL0_L7_q3_decade`i' tempL0_L7_q5_decade`i' tempL0_L7_q6_decade`i' tempL0_L7_q8_decade`i'  rainfall thickfog_report if decade_1==`i', absorb(year week) vce(r)
mat beta=e(b)
svmat double beta, names(matcol)
egen test_L0L7_q8_decade`i'=max(betatempL0_L7_q8_decade`i')
drop betatempL0_L7_q1_decade`i' betatempL0_L7_q2_decade`i' betatempL0_L7_q3_decade`i' betatempL0_L7_q5_decade`i' betatempL0_L7_q6_decade`i' betatempL0_L7_q8_decade`i' betarainfall betathickfog_report beta_cons

}

gen coeff_L0L7_q8=test_L0L7_q8_decade1 if year>=1873 & year<=1879
replace coeff_L0L7_q8=test_L0L7_q8_decade2 if year>=1880 & year<=1889
replace coeff_L0L7_q8=test_L0L7_q8_decade3 if year>=1890 & year<=1899
replace coeff_L0L7_q8=test_L0L7_q8_decade4 if year>=1900 & year<=1914
replace coeff_L0L7_q8=test_L0L7_q8_decade5 if year>=1919 & year<=1929
replace coeff_L0L7_q8=test_L0L7_q8_decade6 if year>=1930 & year<=1939
replace coeff_L0L7_q8=test_L0L7_q8_decade7 if year>=1949 & year<=1965
drop test_L0L7*

tsset date
twoway (tsline digestive_ratio if year<=1914, graphregion(fcolor(white)) lc(gs10) yaxis(1) title("Panel B", color(black) size(medium)) xtitle("Week") ytitle("Digestive deaths per 100 non-digestive deaths") )  (scatter coeff_L0L7_q8 date if year<=1914, graphregion(fcolor(white)) legend(off) yaxis(2) msymbol(D) mc(black) mfc(gs16) ytitle("Regression coefficient size", axis(2)) ) || /// 
(tsline digestive_ratio if year>=1919 & year<1941, graphregion(fcolor(white)) lc(gs10) yaxis(1) ) (scatter coeff_L0L7_q8 date if year>=1919 & year<1941, graphregion(fcolor(white)) yaxis(2) msymbol(D) mc(black) mfc(gs16) ) || ///
(tsline digestive_ratio if year>1940, graphregion(fcolor(white)) lc(gs10) yaxis(1) ) (scatter coeff_L0L7_q8 date if year>1940, graphregion(fcolor(white)) yaxis(2) msymbol(D) mc(black) mfc(gs16) ) 
graph save Graph "Figure1_panelB", replace
restore 

gr combine Figure1_panelA.gph Figure1_panelB.gph, altshrink graphregion(fcolor(white))
graph save Graph "Figure1", replace
graph export "Figure1.pdf", replace as(pdf)
graph export "Figure1.tif", replace as(tif)


erase "Figure1_panelA.gph"
erase "Figure1_panelB.gph"
********************************************************************************

