
//SET OUTPUT FOLDER
cd "$root\results\figure_7"

//INLOAD MAIN DATA (constructed in "combine_datasets.do")
use "$root\intermediate_datasets\by_age_data.dta" 


********** Given every year the temperature patterns of 1904
* Why 1904? It has the median number of q8 and q7 events
preserve
keep if year==1904
keep week temp_F* temp_L*

foreach dist of numlist 7(1)0{
foreach i of numlist 1 2 3 5 6 7 8 {
rename temp_L`dist'_q`i' tmed_L`dist'_q`i'
}
}

foreach dist of numlist 1(1)5{
foreach i of numlist 1 2 3 5 6 7 8 {
rename temp_F`dist'_q`i' tmed_F`dist'_q`i'
}
}
sort week
save "$root\temp\temps1904", replace
restore

sort week
merge week using "$root\temp\temps1904"
tab _merge

foreach dist of numlist 7(1)0{
foreach i of numlist 7 8 {
replace tmed_L`dist'_q`i'=0 if tmed_L`dist'_q`i'==.
}
}

* drop years for which infant mortality is not observed
drop if year<1876

* focus on the period before WWI
keep if year<=1914

* drop reference temperature bins
drop temp_L0_q4 temp_L1_q4 temp_L2_q4 temp_L3_q4 temp_L4_q4 temp_L5_q4 temp_L6_q4 temp_L7_q4


********************************************************************************
//Results
********************************************************************************

** Run regression of infant mortality on temperature
xi: reghdfe lninfants01 temp_L* rainfall thickfog_report, absorb(year week) vce(r)

** Now interact the estimated coefficients with actual mortliaty and either actual
** or counterfactual temperature
gen heat_infants01=infants01*(1- 1/(exp(_b[temp_L0_q8])^temp_L0_q8 * exp(_b[temp_L1_q8])^temp_L1_q8 * exp(_b[temp_L2_q8])^temp_L2_q8 * exp(_b[temp_L3_q8])^temp_L3_q8 *exp(_b[temp_L4_q8])^temp_L4_q8 *exp(_b[temp_L5_q8])^temp_L5_q8 *exp(_b[temp_L6_q8])^temp_L6_q8 *exp(_b[temp_L7_q8])^temp_L7_q8))
gen heatmed_infants01=infants01*(1- 1/(exp(_b[temp_L0_q8])^tmed_L0_q8 * exp(_b[temp_L1_q8])^tmed_L1_q8 * exp(_b[temp_L2_q8])^tmed_L2_q8 * exp(_b[temp_L3_q8])^tmed_L3_q8 *exp(_b[temp_L4_q8])^tmed_L4_q8 *exp(_b[temp_L5_q8])^tmed_L5_q8 *exp(_b[temp_L6_q8])^tmed_L6_q8 *exp(_b[temp_L7_q8])^tmed_L7_q8))

** Sum deaths by year
collapse (sum) heat_* heatmed* infants01, by(year)
gen infants01_NOHEAT=infants01-heat_infants01
gen infants01_MEDHEAT=infants01-heat_infants01+heatmed_infants01


twoway line infants01_NOHEAT year || line infants01_MEDHEAT year|| line infants01 year, scheme(plotplain) legend(lab(1 "Without heat deaths (q8)") lab(2 "With avg. temp year") lab(3 "Actual deaths"))
graph export "figure7.pdf", replace


***
