clear all
set more off

*Set path
*global root "C:\Users\jbn102\Dropbox\Current_work\London_temperature" /* Casper's path */
global root "C:\Users\walke\Dropbox\London_temperature\replication_files"

//SET OUTPUT FOLDER
cd "$root\results\table_3"

******************************************************************************
********** Part 1: Estimate hot and cold deaths for each period using 
* the estimated temperature-mortality relationship for different periods
******************************************************************************

//INLOAD MAIN DATA (constructed in "combine_datasets.do")
use "$root\intermediate_datasets\by_age_data.dta" 

*** Focus on years for which all age groups are available
drop if year<1876

*** Identify weeks in each period
gen weeks_pre_WWI=0
replace weeks_pre_WWI=1 if year<1920
gen weeks_interwar=0
replace weeks_interwar=1 if year>1918 & year<1940
gen weeks_post_WWII=0
replace weeks_post_WWII=1 if year>1940 & year<1970

*** Drop reference temperature bin
drop temp_L0_q4 temp_L1_q4 temp_L2_q4 temp_L3_q4 temp_L4_q4 temp_L5_q4 temp_L6_q4 temp_L7_q4

// Pre-WWI period
preserve
keep if year<=1914
foreach i in infants01 children15 age_young age_adult age_middle age_elderly {
xi: reghdfe ln`i' temp_L* rainfall thickfog_report, absorb(year week) vce(r)

** Now interact the estimated coefficients with actual temperature and mortality values to generated predicted deaths
gen heat_`i'=`i'*(1- 1/(exp(_b[temp_L0_q8])^temp_L0_q8 * exp(_b[temp_L1_q8])^temp_L1_q8 * exp(_b[temp_L2_q8])^temp_L2_q8 * exp(_b[temp_L3_q8])^temp_L3_q8 *exp(_b[temp_L4_q8])^temp_L4_q8 *exp(_b[temp_L5_q8])^temp_L5_q8 *exp(_b[temp_L6_q8])^temp_L6_q8 *exp(_b[temp_L7_q8])^temp_L7_q8))
gen cold_`i'=`i'*(1- 1/(exp(_b[temp_L0_q1])^temp_L0_q1 * exp(_b[temp_L0_q2])^temp_L0_q2 * exp(_b[temp_L0_q3])^temp_L0_q3 * exp(_b[temp_L1_q1])^temp_L1_q1 *exp(_b[temp_L1_q2])^temp_L1_q2 * exp(_b[temp_L1_q3])^temp_L1_q3 *exp(_b[temp_L2_q1])^temp_L2_q1 *exp(_b[temp_L2_q2])^temp_L2_q2 *exp(_b[temp_L2_q3])^temp_L2_q3 *exp(_b[temp_L3_q1])^temp_L3_q1 *exp(_b[temp_L3_q2])^temp_L3_q2 *exp(_b[temp_L3_q3])^temp_L3_q3 *exp(_b[temp_L4_q1])^temp_L4_q1 *exp(_b[temp_L4_q2])^temp_L4_q2 *exp(_b[temp_L4_q3])^temp_L4_q3 *exp(_b[temp_L5_q1])^temp_L5_q1 *exp(_b[temp_L5_q2])^temp_L5_q2 *exp(_b[temp_L5_q3])^temp_L5_q3 *exp(_b[temp_L6_q1])^temp_L6_q1 *exp(_b[temp_L6_q2])^temp_L6_q2 *exp(_b[temp_L6_q3])^temp_L6_q3 *exp(_b[temp_L7_q1])^temp_L7_q1 *exp(_b[temp_L7_q2])^temp_L7_q2 *exp(_b[temp_L7_q3])^temp_L7_q3))

foreach j in pre_WWI  {
gen heat_`j'_`i'=heat_`i'*weeks_`j'
gen cold_`j'_`i'=cold_`i'*weeks_`j'
gen total_`j'_`i'=`i'*weeks_`j'
}
}

** Sum deaths by period
collapse (sum) heat_pre_WWI* cold_pre_WWI* total_pre_WWI* weeks_pre_WWI
gen counter=1
reshape long heat_pre_WWI cold_pre_WWI total_pre_WWI, i(counter) j(age) string

sort age
outsheet using "actual_temp_preWWI.csv", comma names replace
restore


// Interwar period
preserve
keep if year>1917 & year<1940
foreach i in infants01 children15 age_young age_adult age_middle age_elderly {
xi: reghdfe ln`i' temp_L* rainfall thickfog_report, absorb(year week) vce(r)
gen heat_`i'=`i'*(1- 1/(exp(_b[temp_L0_q8])^temp_L0_q8 * exp(_b[temp_L1_q8])^temp_L1_q8 * exp(_b[temp_L2_q8])^temp_L2_q8 * exp(_b[temp_L3_q8])^temp_L3_q8 *exp(_b[temp_L4_q8])^temp_L4_q8 *exp(_b[temp_L5_q8])^temp_L5_q8 *exp(_b[temp_L6_q8])^temp_L6_q8 *exp(_b[temp_L7_q8])^temp_L7_q8))
gen cold_`i'=`i'*(1- 1/(exp(_b[temp_L0_q1])^temp_L0_q1 * exp(_b[temp_L0_q2])^temp_L0_q2 * exp(_b[temp_L0_q3])^temp_L0_q3 * exp(_b[temp_L1_q1])^temp_L1_q1 *exp(_b[temp_L1_q2])^temp_L1_q2 * exp(_b[temp_L1_q3])^temp_L1_q3 *exp(_b[temp_L2_q1])^temp_L2_q1 *exp(_b[temp_L2_q2])^temp_L2_q2 *exp(_b[temp_L2_q3])^temp_L2_q3 *exp(_b[temp_L3_q1])^temp_L3_q1 *exp(_b[temp_L3_q2])^temp_L3_q2 *exp(_b[temp_L3_q3])^temp_L3_q3 *exp(_b[temp_L4_q1])^temp_L4_q1 *exp(_b[temp_L4_q2])^temp_L4_q2 *exp(_b[temp_L4_q3])^temp_L4_q3 *exp(_b[temp_L5_q1])^temp_L5_q1 *exp(_b[temp_L5_q2])^temp_L5_q2 *exp(_b[temp_L5_q3])^temp_L5_q3 *exp(_b[temp_L6_q1])^temp_L6_q1 *exp(_b[temp_L6_q2])^temp_L6_q2 *exp(_b[temp_L6_q3])^temp_L6_q3 *exp(_b[temp_L7_q1])^temp_L7_q1 *exp(_b[temp_L7_q2])^temp_L7_q2 *exp(_b[temp_L7_q3])^temp_L7_q3))

foreach j in interwar  {
gen heat_`j'_`i'=heat_`i'*weeks_`j'
gen cold_`j'_`i'=cold_`i'*weeks_`j'
gen total_`j'_`i'=`i'*weeks_`j'
}
}

collapse (sum) heat_interwar* cold_interwar* total_interwar* weeks_interwar*
gen counter=1
reshape long heat_interwar cold_interwar total_interwar , i(counter) j(age) string
drop counter

sort age
outsheet using "actual_temp_Interwar.csv", comma names replace
restore


// Post-WWII period
preserve
keep if year>1940 
foreach i in infants01 children15 age_young age_adult age_middle age_elderly {
xi: reghdfe ln`i' temp_L* rainfall thickfog_report , absorb(year week) vce(r)
gen heat_`i'=`i'*(1- 1/(exp(_b[temp_L0_q8])^temp_L0_q8 * exp(_b[temp_L1_q8])^temp_L1_q8 * exp(_b[temp_L2_q8])^temp_L2_q8 * exp(_b[temp_L3_q8])^temp_L3_q8 *exp(_b[temp_L4_q8])^temp_L4_q8 *exp(_b[temp_L5_q8])^temp_L5_q8 *exp(_b[temp_L6_q8])^temp_L6_q8 *exp(_b[temp_L7_q8])^temp_L7_q8))
gen cold_`i'=`i'*(1- 1/(exp(_b[temp_L0_q1])^temp_L0_q1 * exp(_b[temp_L0_q2])^temp_L0_q2 * exp(_b[temp_L0_q3])^temp_L0_q3 * exp(_b[temp_L1_q1])^temp_L1_q1 *exp(_b[temp_L1_q2])^temp_L1_q2 * exp(_b[temp_L1_q3])^temp_L1_q3 *exp(_b[temp_L2_q1])^temp_L2_q1 *exp(_b[temp_L2_q2])^temp_L2_q2 *exp(_b[temp_L2_q3])^temp_L2_q3 *exp(_b[temp_L3_q1])^temp_L3_q1 *exp(_b[temp_L3_q2])^temp_L3_q2 *exp(_b[temp_L3_q3])^temp_L3_q3 *exp(_b[temp_L4_q1])^temp_L4_q1 *exp(_b[temp_L4_q2])^temp_L4_q2 *exp(_b[temp_L4_q3])^temp_L4_q3 *exp(_b[temp_L5_q1])^temp_L5_q1 *exp(_b[temp_L5_q2])^temp_L5_q2 *exp(_b[temp_L5_q3])^temp_L5_q3 *exp(_b[temp_L6_q1])^temp_L6_q1 *exp(_b[temp_L6_q2])^temp_L6_q2 *exp(_b[temp_L6_q3])^temp_L6_q3 *exp(_b[temp_L7_q1])^temp_L7_q1 *exp(_b[temp_L7_q2])^temp_L7_q2 *exp(_b[temp_L7_q3])^temp_L7_q3))

foreach j in post_WWII  {
gen heat_`j'_`i'=heat_`i'*weeks_`j'
gen cold_`j'_`i'=cold_`i'*weeks_`j'
gen total_`j'_`i'=`i'*weeks_`j'
}
}

collapse (sum) heat_post_WWII* cold_post_WWII* total_post_WWII* weeks_post_WWII*
gen counter=1
reshape long heat_post_WWII cold_post_WWII total_post_WWII, i(counter) j(age) string
drop counter

sort age
outsheet using "actual_temp_PostWWII.csv", comma names replace
restore
clear


******************************************************************************
********** Part 2: Counterfactual deaths in the interwar and Post-WWII periods
********** using the temp-mort relationship estimated in the Pre-WWI period
******************************************************************************

//INLOAD MAIN DATA (constructed in "combine_datasets.do")
use "$root\intermediate_datasets\by_age_data.dta", clear

*** Focus on years for which all age groups are available
drop if year<1876

*** Identify weeks in each period
gen weeks_pre_WWI=0
replace weeks_pre_WWI=1 if year<1920
gen weeks_interwar=0
replace weeks_interwar=1 if year>1918 & year<1940
gen weeks_post_WWII=0
replace weeks_post_WWII=1 if year>1940 & year<1970

***** Create counterfactual temperature -- higher by 1.5 degrees C
gen counter_max_temp=oxford_max_temp+1.5*9/5
gen counter_min_temp=oxford_min_temp+1.5*9/5

*** Counterfactual temp bins
gen eq_counter=.
replace eq_counter=1 if counter_min_temp<25
replace eq_counter=2 if counter_min_temp>=25 & counter_min_temp<30
replace eq_counter=3 if counter_min_temp>=30 & counter_min_temp<35
replace eq_counter=5 if counter_max_temp>=65 & counter_max_temp<70
replace eq_counter=6 if counter_max_temp>=70 & counter_max_temp<75
replace eq_counter=7 if counter_max_temp>=75 & counter_max_temp<80
replace eq_counter=8 if counter_max_temp>=80
replace eq_counter=4 if eq_counter==.


*Prepare counterfactual temperature variables
forvalues i = 1/8{
gen counter_q`i'= 1 if eq_counter==`i'
replace counter_q`i'=0 if counter_q`i'==. 
}

*LEAD/LAGS FOR 7 BINS (4TH BIN OMITTED(
sort year week
foreach dist of numlist 7(1)0{
foreach i of numlist 1 2 3 5 6 7 8 {
gen counter_L`dist'_q`i'= counter_q`i'[_n-`dist']
}
}

*** Drop reference temperature bin
drop temp_L0_q4 temp_L1_q4 temp_L2_q4 temp_L3_q4 temp_L4_q4 temp_L5_q4 temp_L6_q4 temp_L7_q4

** Counter for weeks
gen weeks=1

// Estimate the PRE-WWI Temp-Mort relationship and then apply to mortality rates
** from other periods with either real or counterfactual temperature levels

** First run the regression on the pre-WWI data to obtain coefficents
foreach i in infants01 children15 age_young age_adult age_middle age_elderly {
xi: reghdfe ln`i' temp_L* rainfall thickfog_report if year<1919, absorb(year week) vce(r)

** Now we apply these coefficients to the actual deaths in other periods with 
** actual temperature observations in those periods
gen heat_`i'=`i'*(1- 1/(exp(_b[temp_L0_q8])^temp_L0_q8 * exp(_b[temp_L1_q8])^temp_L1_q8 * exp(_b[temp_L2_q8])^temp_L2_q8 * exp(_b[temp_L3_q8])^temp_L3_q8 *exp(_b[temp_L4_q8])^temp_L4_q8 *exp(_b[temp_L5_q8])^temp_L5_q8 *exp(_b[temp_L6_q8])^temp_L6_q8 *exp(_b[temp_L7_q8])^temp_L7_q8))
gen cold_`i'=`i'*(1- 1/(exp(_b[temp_L0_q1])^temp_L0_q1 * exp(_b[temp_L0_q2])^temp_L0_q2 * exp(_b[temp_L0_q3])^temp_L0_q3 * exp(_b[temp_L1_q1])^temp_L1_q1 *exp(_b[temp_L1_q2])^temp_L1_q2 * exp(_b[temp_L1_q3])^temp_L1_q3 *exp(_b[temp_L2_q1])^temp_L2_q1 *exp(_b[temp_L2_q2])^temp_L2_q2 *exp(_b[temp_L2_q3])^temp_L2_q3 *exp(_b[temp_L3_q1])^temp_L3_q1 *exp(_b[temp_L3_q2])^temp_L3_q2 *exp(_b[temp_L3_q3])^temp_L3_q3 *exp(_b[temp_L4_q1])^temp_L4_q1 *exp(_b[temp_L4_q2])^temp_L4_q2 *exp(_b[temp_L4_q3])^temp_L4_q3 *exp(_b[temp_L5_q1])^temp_L5_q1 *exp(_b[temp_L5_q2])^temp_L5_q2 *exp(_b[temp_L5_q3])^temp_L5_q3 *exp(_b[temp_L6_q1])^temp_L6_q1 *exp(_b[temp_L6_q2])^temp_L6_q2 *exp(_b[temp_L6_q3])^temp_L6_q3 *exp(_b[temp_L7_q1])^temp_L7_q1 *exp(_b[temp_L7_q2])^temp_L7_q2 *exp(_b[temp_L7_q3])^temp_L7_q3))

** Now we apply these coefficients to the actual deaths in other periods with 
** counterfactual temperature observations in those periods
gen heat_counter_`i'=`i'*(1- 1/(exp(_b[temp_L0_q8])^counter_L0_q8 * exp(_b[temp_L1_q8])^counter_L1_q8 * exp(_b[temp_L2_q8])^counter_L2_q8 * exp(_b[temp_L3_q8])^counter_L3_q8 *exp(_b[temp_L4_q8])^counter_L4_q8 *exp(_b[temp_L5_q8])^counter_L5_q8 *exp(_b[temp_L6_q8])^counter_L6_q8 *exp(_b[temp_L7_q8])^counter_L7_q8 ))
gen cold_counter_`i'=`i'*(1- 1/(exp(_b[temp_L0_q1])^counter_L0_q1 * exp(_b[temp_L0_q2])^counter_L0_q2 * exp(_b[temp_L0_q3])^counter_L0_q3 * exp(_b[temp_L1_q1])^counter_L1_q1 *exp(_b[temp_L1_q2])^counter_L1_q2 * exp(_b[temp_L1_q3])^counter_L1_q3 *exp(_b[temp_L2_q1])^counter_L2_q1 *exp(_b[temp_L2_q2])^counter_L2_q2 *exp(_b[temp_L2_q3])^counter_L2_q3 *exp(_b[temp_L3_q1])^counter_L3_q1 *exp(_b[temp_L3_q2])^counter_L3_q2 *exp(_b[temp_L3_q3])^counter_L3_q3 *exp(_b[temp_L4_q1])^counter_L4_q1 *exp(_b[temp_L4_q2])^counter_L4_q2 *exp(_b[temp_L4_q3])^counter_L4_q3 *exp(_b[temp_L5_q1])^counter_L5_q1 *exp(_b[temp_L5_q2])^counter_L5_q2 *exp(_b[temp_L5_q3])^counter_L5_q3 *exp(_b[temp_L6_q1])^counter_L6_q1 *exp(_b[temp_L6_q2])^counter_L6_q2 *exp(_b[temp_L6_q3])^counter_L6_q3 *exp(_b[temp_L7_q1])^counter_L7_q1 *exp(_b[temp_L7_q2])^counter_L7_q2 *exp(_b[temp_L7_q3])^counter_L7_q3))
}

gen period=""
replace period="interwar" if year>1918 & year<1940
replace period="post_WWII" if year>1940
drop if period==""

** Collapse to sum up hot and cold deaths
collapse (sum) heat_* cold_* weeks, by(period)
reshape long heat_ heat_counter_ cold_ cold_counter_ , i(period) j(age) string
sort period age
order age period heat_ cold_ heat_counter_ cold_counter_

** Save
outsheet using "counterfactual_with_preWWI_temp_mort_effects.csv", comma names replace
clear



******************************************************************************
********** Part 3: Estimate hot and cold deaths for each period using 
* counterfactual temperatures that are higher by 1.5C
******************************************************************************

//INLOAD MAIN DATA (constructed in "combine_datasets.do")
use "$root\intermediate_datasets\by_age_data.dta", clear

*** Focus on years for which all age groups are available
drop if year<1876

*** Identify weeks in each period
gen weeks_pre_WWI=0
replace weeks_pre_WWI=1 if year<1920
gen weeks_interwar=0
replace weeks_interwar=1 if year>1918 & year<1940
gen weeks_post_WWII=0
replace weeks_post_WWII=1 if year>1940 & year<1970

***** Create counterfactual temperature -- higher by 1.5 degrees C
gen counter_max_temp=oxford_max_temp+1.5*9/5
gen counter_min_temp=oxford_min_temp+1.5*9/5

*** Counterfactual temp bins
gen eq_counter=.
replace eq_counter=1 if counter_min_temp<25
replace eq_counter=2 if counter_min_temp>=25 & counter_min_temp<30
replace eq_counter=3 if counter_min_temp>=30 & counter_min_temp<35
replace eq_counter=5 if counter_max_temp>=65 & counter_max_temp<70
replace eq_counter=6 if counter_max_temp>=70 & counter_max_temp<75
replace eq_counter=7 if counter_max_temp>=75 & counter_max_temp<80
replace eq_counter=8 if counter_max_temp>=80
replace eq_counter=4 if eq_counter==.


*Prepare counterfactual temperature variables
forvalues i = 1/8{
gen counter_q`i'= 1 if eq_counter==`i'
replace counter_q`i'=0 if counter_q`i'==. 
}

*LEAD/LAGS FOR 7 BINS (4TH BIN OMITTED(
sort year week
foreach dist of numlist 7(1)0{
foreach i of numlist 1 2 3 5 6 7 8 {
gen counter_L`dist'_q`i'= counter_q`i'[_n-`dist']
}
}


*** Drop reference temperature bin
drop temp_L0_q4 temp_L1_q4 temp_L2_q4 temp_L3_q4 temp_L4_q4 temp_L5_q4 temp_L6_q4 temp_L7_q4

// Pre-WWI period
preserve
keep if year<=1914
foreach i in infants01 children15 age_young age_adult age_middle age_elderly {
xi: reghdfe ln`i' temp_L* rainfall thickfog_report, absorb(year week) vce(r)

** Now interact the estimated coefficients with counterfactual temperature and actual mortality values to generated predicted deaths
gen heat_cnt_`i'=`i'*(1- 1/(exp(_b[temp_L0_q8])^counter_L0_q8 * exp(_b[temp_L1_q8])^counter_L1_q8 * exp(_b[temp_L2_q8])^counter_L2_q8 * exp(_b[temp_L3_q8])^counter_L3_q8 *exp(_b[temp_L4_q8])^counter_L4_q8 *exp(_b[temp_L5_q8])^counter_L5_q8 *exp(_b[temp_L6_q8])^counter_L6_q8 *exp(_b[temp_L7_q8])^counter_L7_q8 ))
gen cold_cnt_`i'=`i'*(1- 1/(exp(_b[temp_L0_q1])^counter_L0_q1 * exp(_b[temp_L0_q2])^counter_L0_q2 * exp(_b[temp_L0_q3])^counter_L0_q3 * exp(_b[temp_L1_q1])^counter_L1_q1 *exp(_b[temp_L1_q2])^counter_L1_q2 * exp(_b[temp_L1_q3])^counter_L1_q3 *exp(_b[temp_L2_q1])^counter_L2_q1 *exp(_b[temp_L2_q2])^counter_L2_q2 *exp(_b[temp_L2_q3])^counter_L2_q3 *exp(_b[temp_L3_q1])^counter_L3_q1 *exp(_b[temp_L3_q2])^counter_L3_q2 *exp(_b[temp_L3_q3])^counter_L3_q3 *exp(_b[temp_L4_q1])^counter_L4_q1 *exp(_b[temp_L4_q2])^counter_L4_q2 *exp(_b[temp_L4_q3])^counter_L4_q3 *exp(_b[temp_L5_q1])^counter_L5_q1 *exp(_b[temp_L5_q2])^counter_L5_q2 *exp(_b[temp_L5_q3])^counter_L5_q3 *exp(_b[temp_L6_q1])^counter_L6_q1 *exp(_b[temp_L6_q2])^counter_L6_q2 *exp(_b[temp_L6_q3])^counter_L6_q3 *exp(_b[temp_L7_q1])^counter_L7_q1 *exp(_b[temp_L7_q2])^counter_L7_q2 *exp(_b[temp_L7_q3])^counter_L7_q3))

foreach j in pre_WWI  {
gen heat_cnt_`j'_`i'=heat_cnt_`i'*weeks_`j'
gen cold_cnt_`j'_`i'=cold_cnt_`i'*weeks_`j'
}
}

** Sum deaths by period
collapse (sum) heat_cnt_pre_WWI* cold_cnt_pre_WWI* weeks_pre_WWI
gen counter=1
reshape long heat_cnt_pre_WWI cold_cnt_pre_WWI, i(counter) j(age) string

sort age
outsheet using "counterfactual_temp_preWWI.csv", comma names replace
restore


// Interwar period
preserve
keep if year>1917 & year<1940
foreach i in infants01 children15 age_young age_adult age_middle age_elderly {
xi: reghdfe ln`i' temp_L* rainfall thickfog_report, absorb(year week) vce(r)
gen heat_cnt_`i'=`i'*(1- 1/(exp(_b[temp_L0_q8])^counter_L0_q8 * exp(_b[temp_L1_q8])^counter_L1_q8 * exp(_b[temp_L2_q8])^counter_L2_q8 * exp(_b[temp_L3_q8])^counter_L3_q8 *exp(_b[temp_L4_q8])^counter_L4_q8 *exp(_b[temp_L5_q8])^counter_L5_q8 *exp(_b[temp_L6_q8])^counter_L6_q8 *exp(_b[temp_L7_q8])^counter_L7_q8 ))
gen cold_cnt_`i'=`i'*(1- 1/(exp(_b[temp_L0_q1])^counter_L0_q1 * exp(_b[temp_L0_q2])^counter_L0_q2 * exp(_b[temp_L0_q3])^counter_L0_q3 * exp(_b[temp_L1_q1])^counter_L1_q1 *exp(_b[temp_L1_q2])^counter_L1_q2 * exp(_b[temp_L1_q3])^counter_L1_q3 *exp(_b[temp_L2_q1])^counter_L2_q1 *exp(_b[temp_L2_q2])^counter_L2_q2 *exp(_b[temp_L2_q3])^counter_L2_q3 *exp(_b[temp_L3_q1])^counter_L3_q1 *exp(_b[temp_L3_q2])^counter_L3_q2 *exp(_b[temp_L3_q3])^counter_L3_q3 *exp(_b[temp_L4_q1])^counter_L4_q1 *exp(_b[temp_L4_q2])^counter_L4_q2 *exp(_b[temp_L4_q3])^counter_L4_q3 *exp(_b[temp_L5_q1])^counter_L5_q1 *exp(_b[temp_L5_q2])^counter_L5_q2 *exp(_b[temp_L5_q3])^counter_L5_q3 *exp(_b[temp_L6_q1])^counter_L6_q1 *exp(_b[temp_L6_q2])^counter_L6_q2 *exp(_b[temp_L6_q3])^counter_L6_q3 *exp(_b[temp_L7_q1])^counter_L7_q1 *exp(_b[temp_L7_q2])^counter_L7_q2 *exp(_b[temp_L7_q3])^counter_L7_q3))

foreach j in interwar  {
gen heat_cnt_`j'_`i'=heat_cnt_`i'*weeks_`j'
gen cold_cnt_`j'_`i'=cold_cnt_`i'*weeks_`j'
}
}

collapse (sum) heat_cnt_interwar* cold_cnt_interwar* weeks_interwar*
gen counter=1
reshape long heat_cnt_interwar cold_cnt_interwar, i(counter) j(age) string
drop counter

sort age
outsheet using "counterfactual_temp_Interwar.csv", comma names replace
restore


// Post-WWII period
preserve
keep if year>1940 
foreach i in infants01 children15 age_young age_adult age_middle age_elderly {
xi: reghdfe ln`i' temp_L* rainfall thickfog_report , absorb(year week) vce(r)
gen heat_cnt_`i'=`i'*(1- 1/(exp(_b[temp_L0_q8])^counter_L0_q8 * exp(_b[temp_L1_q8])^counter_L1_q8 * exp(_b[temp_L2_q8])^counter_L2_q8 * exp(_b[temp_L3_q8])^counter_L3_q8 *exp(_b[temp_L4_q8])^counter_L4_q8 *exp(_b[temp_L5_q8])^counter_L5_q8 *exp(_b[temp_L6_q8])^counter_L6_q8 *exp(_b[temp_L7_q8])^counter_L7_q8 ))
gen cold_cnt_`i'=`i'*(1- 1/(exp(_b[temp_L0_q1])^counter_L0_q1 * exp(_b[temp_L0_q2])^counter_L0_q2 * exp(_b[temp_L0_q3])^counter_L0_q3 * exp(_b[temp_L1_q1])^counter_L1_q1 *exp(_b[temp_L1_q2])^counter_L1_q2 * exp(_b[temp_L1_q3])^counter_L1_q3 *exp(_b[temp_L2_q1])^counter_L2_q1 *exp(_b[temp_L2_q2])^counter_L2_q2 *exp(_b[temp_L2_q3])^counter_L2_q3 *exp(_b[temp_L3_q1])^counter_L3_q1 *exp(_b[temp_L3_q2])^counter_L3_q2 *exp(_b[temp_L3_q3])^counter_L3_q3 *exp(_b[temp_L4_q1])^counter_L4_q1 *exp(_b[temp_L4_q2])^counter_L4_q2 *exp(_b[temp_L4_q3])^counter_L4_q3 *exp(_b[temp_L5_q1])^counter_L5_q1 *exp(_b[temp_L5_q2])^counter_L5_q2 *exp(_b[temp_L5_q3])^counter_L5_q3 *exp(_b[temp_L6_q1])^counter_L6_q1 *exp(_b[temp_L6_q2])^counter_L6_q2 *exp(_b[temp_L6_q3])^counter_L6_q3 *exp(_b[temp_L7_q1])^counter_L7_q1 *exp(_b[temp_L7_q2])^counter_L7_q2 *exp(_b[temp_L7_q3])^counter_L7_q3))

foreach j in post_WWII  {
gen heat_cnt_`j'_`i'=heat_cnt_`i'*weeks_`j'
gen cold_cnt_`j'_`i'=cold_cnt_`i'*weeks_`j'
}
}

collapse (sum) heat_cnt_post_WWII* cold_cnt_post_WWII* weeks_post_WWII*
gen counter=1
reshape long heat_cnt_post_WWII cold_cnt_post_WWII, i(counter) j(age) string
drop counter

sort age
outsheet using "counterfactual_temp_PostWWII.csv", comma names replace
restore
clear





****
